# Zope Weather - (c) 2002 Jerome Alet
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
#
# author: Jerome Alet - <alet@librelogiciel.com>
#
# $Id: $
#
# $Log: $
#

# This software contains code adapted from the Gnome Weather applet
# written in C language by Spiros Papadimitriou and licensed
# under the GNU General Public License of the Free Software Foundation

# This software contains pictures from the Evolution Mail User Agent
# written by Ximian and distributed under the GNU General Public
# License of the Free Software Foundation

from Interface import Base

class IZWeather(Base) :
    """Zope Weather interface"""
    def refresh(self) :
	"""Refreshes the weather information from NOAA's metar server."""

    def editStation(self, NOAACode, REQUEST=None) :
	"""Edits the station location code."""

    def getFullReport(self):
	"""
	Return the complete weather report.
	"""

    def getTemperatureCelsius(self):
	"""
	Return the temperature in degrees Celsius.
	"""

    def getTemperatureFahrenheit(self):
	"""
	Return the temperature in degrees Fahrenheit.
	"""

    def getDewPointCelsius(self):
	"""
	Return dewpoint in degrees Celsius.
	"""

    def getDewPointFahrenheit(self):
	"""
	Return dewpoint in degrees Fahrenheit.
	"""

    def getWindSpeed(self):
	"""
	Return the wind speed in meters per second.
	"""

    def getWindDirection(self):
	"""
	Return wind direction in degrees.
	"""

    def getWindCompass(self):
	"""
	Return wind direction as compass direction
	(e.g. NE or SSE)
	"""

    def getVisibilityKilometers(self):
	"""
	Return visibility in km.
	"""

    def getVisibilityMiles(self):
	"""
	Return visibility in miles.
	"""

    def getHumidity(self):
	"""
	Return relative humidity in percent.
	"""

    def getPressure(self):
	"""
	Return pressure in hPa.
	"""

    def getRawMetarCode(self):
	"""
	Return the encoded weather report.
	"""

    def getWeather(self):
	"""
	Return short weather conditions
	"""

    def getSkyConditions(self):
	"""
	Return sky conditions
	"""

    def getStationName(self):
	"""
	Return full station name
	"""

    def getCycle(self):
	"""
	Return cycle value.
	The cycle value is not the frequency or delay
	between observations but the "time slot" in
	which the observation was made. There are 24
	cycle slots every day which usually last from
	N:45 to N+1:45. The cycle from 23:45 to 0:45
	is cycle 0.
	"""

    def getStationPosition(self):
	"""
	Return latitude, longitude and height above sea level of station
	as a tuple. Some stations don't deliver height, for those,
	None is returned as height.
	The lat/longs are expressed as follows:
	xx-yyd
	where xx is degrees, yy minutes and d the direction.
	Thus 51-14N means 51 degrees, 14 minutes north.
	d may take the values N, S for latitues and W, E for
	longitudes. Latitude and Longitude may include seconds.
	Height is always given as meters above sea level,
	including a trailing M.
	Schipohl Int. Airport Amsterdam has, for example:
	('52-18N', '004-46E', '-2M')
	Moenchengladbach (where I live):
	('51-14N', '063-03E', None)
	"""

    def getStationLatitude(self) :
	"""
	Return the station's latitude in dd-mm[-ss]D format :
	       dd : degrees
	       mm : minutes
	       ss : seconds
	       D : direction (N, S, E, W)
	"""

    def getStationLongitude(self) :
	"""
	Return the station's longitude in dd-mm[-ss]D format :
	       dd : degrees
	       mm : minutes
	       ss : seconds
	       D : direction (N, S, E, W)
	"""

    def getStationHeight(self) :
	"""
	Return the station's height above the sea in meters.
	"""

    def getTime(self):
	"""
	Return the time when the observation was made.
	Note that this is *not* the time when the report
	was fetched by us
	Format:	 YYYY.MM.DD HHMM UTC
	Example: 2002.04.01 1020 UTC
	"""

    def getPixmap(self):
	"""
	Return a suggested pixmap name, without extension, depending on current weather.
	"""

    def getPixmapURL(self):
	"""
	Return the suggested pixmap url, using default images included in ZWeather.
	"""
