# Zope Weather - (c) 2002 Jerome Alet
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
#
# author: Jerome Alet - <alet@librelogiciel.com>
#
# $Id: $
#
# $Log: $
#

# This software contains code adapted from the Gnome Weather applet
# written in C language by Spiros Papadimitriou and licensed
# under the GNU General Public License of the Free Software Foundation

# This software contains pictures from the Evolution Mail User Agent
# written by Ximian and distributed under the GNU General Public
# License of the Free Software Foundation

import time

from AccessControl import ClassSecurityInfo, getSecurityManager
from Acquisition import Implicit
from Globals import DTMLFile, Persistent, InitializeClass, MessageDialog
from AccessControl.Role import RoleManager
from OFS.PropertyManager import PropertyManager
from OFS.SimpleItem import SimpleItem, Item_w__name__

from IZWeather import IZWeather
from pymetar import MetarReport

CACHEDURATION = 15.0 * 60.0 # cache reports for 15 minutes

addForm = DTMLFile('dtml/add', globals())

def addFunction(self, id, title='', station=None, REQUEST=None) :
    """Adds the object in the current Folder"""
    if station is not None :
        p = ZWeather(id, title, station)
        dest = self.Destination()
        dest._setObject(id, p)
        if REQUEST :
            REQUEST.RESPONSE.redirect("manage_main")

class ZWeather(Implicit, Persistent, SimpleItem, PropertyManager, MetarReport) :
    """ZWeather implementation"""

    __implements__ = IZWeather

    _properties = (
                      {'id':'title', 'type': 'string', 'mode':'w'},
                      {'id':'station', 'type': 'string', 'mode':'w'},
                  )

    meta_type = "ZWeather"

    security = ClassSecurityInfo()
    security.declareObjectProtected("View")

    def __init__(self, id, title = '', station = '') :
        """Initialization"""
        self.id = id
        self.title = title
        self.editStation(station)

    manage_options = (
          { "label" : "Edit", "action" : "editForm" },
          { "label" : "View", "action" : ""},
        ) + PropertyManager.manage_options + SimpleItem.manage_options

    index_html = None
    security.declareProtected("View", "__call__")
    def __call__(self, REQUEST={}, RESPONSE=None, **kw) :
        """Displays the ZWeather information."""
        if (time.time() - self._lastRefresh) > CACHEDURATION :
            self.refresh()
            
        if self.valid :
            ihtml = ""
            pix = self.getPixmapURL()
            if pix is not None :
                ihtml += '<img src="%s" /> %s<br />' % (pix, ' '.join(self.getStationName().split()))
            t = self.getTemperatureCelsius()
            if t is None :
                t = '?'
            h = self.getHumidity()
            if h is None :
                h = '?'
            p = self.getPressure()
            if p is None :
                p = '?'
            ihtml += "T: %.1fC&nbsp;&nbsp;H: %.0f%%&nbsp;&nbsp;P: %.0f hPa<br />" % (t, h, p)
            c = self.getWindCompass()
            if c is None :
                c = ""
            else :
                c = "from %s" % c
            s = self.getWindSpeed()
            if s is not None :
                ihtml += "Wind: %.1f ms %s<br />" % (s, c)
            s = self.getWeather()
            if s is not None :
                ihtml += "%s<br />" % s
            return '<p>' + ihtml[:-6] + '</p>'

    security.declareProtected("View management screens", "editForm")
    editForm = DTMLFile("dtml/change", globals())

    security.declareProtected("Manage ZWeathers", "refresh")
    def refresh(self) :
        """Refreshes the weather information from NOAA's Metar server."""
        self.fetchMetarReport(self.station)
        self._lastRefresh = time.time()

    security.declareProtected("Manage ZWeathers", "editStation")
    def editStation(self, station, REQUEST=None) :
        """Edits the station code."""
        self._setPropValue("station", station)
        if REQUEST is not None :
            REQUEST.RESPONSE.redirect("editForm")

    security.declareProtected("View", "getWeather")
    security.declareProtected("View", "getFullReport")
    security.declareProtected("View", "getTemperatureCelsius")
    security.declareProtected("View", "getTemperatureFahrenheit")
    security.declareProtected("View", "getDewPointCelsius")
    security.declareProtected("View", "getDewPointFahrenheit")
    security.declareProtected("View", "getWindSpeed")
    security.declareProtected("View", "getWindDirection")
    security.declareProtected("View", "getWindCompass")
    security.declareProtected("View", "getVisibilityKilometers")
    security.declareProtected("View", "getVisibilityMiles")
    security.declareProtected("View", "getHumidity")
    security.declareProtected("View", "getPressure")
    security.declareProtected("View", "getRawMetarCode")
    security.declareProtected("View", "getSkyConditions")
    security.declareProtected("View", "getStationName")
    security.declareProtected("View", "getCycle")
    security.declareProtected("View", "getStationPosition")
    security.declareProtected("View", "getStationLatitude(")
    security.declareProtected("View", "getStationLongitude(")
    security.declareProtected("View", "getStationHeight(")
    security.declareProtected("View", "getTime")
    security.declareProtected("View", "getPixmap")
    
    security.declareProtected("View", "getPixmapURL")
    def getPixmapURL(self) :
        """Returns the suggested pixmap url."""
        pix = self.getPixmap()
        if pix is not None :
            return "misc_/%s/%s" % (self.__class__.__name__, pix)

    def _setPropValue(self, id, value) :
        """Wrapper to get a new report every time the station property is changed."""
        PropertyManager._setPropValue(self, id, value)
        if id == "station" :
            self.refresh()

InitializeClass(ZWeather)
